OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 0%

# Σύνταξη έκθεσης

Τώρα που έχετε ολοκληρώσει την ταυτοποίηση των κινδύνων στην επιχείρησή σας και έχετε καταρτίσει ένα σχέδιο δράσης, μπορείτε να δημιουργήσετε μιαν αναφορά (έκθεση ΕΚ) στην οποία θα παρατίθενται όλα τα αποτελέσματά σας. Μπορείτε, αν θέλετε, να εισάγετε ορισμένα πρόσθετα σχόλια που εκτιμάτε ότι πρέπει να συμπεριλαμβάνονται σε αυτή την αναφορά, στο παρακάτω πεδίο.

Αποθήκευση

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More